@@ -15,11 +15,11 @@ Passwd::Keyring::PWSafe3 - Password storage based on Password Safe encrypted fil
 
 =head1 VERSION
 
-Version 0.2004
+Version 0.2005
 
 =cut
 
-our $VERSION = '0.2004';
+our $VERSION = '0.2006';
 
 our $APP_NAME = "Passwd::Keyring";
 our $FOLDER_NAME = "Perl-Passwd-Keyring";
@@ -27,8 +27,9 @@ our $FOLDER_NAME = "Perl-Passwd-Keyring";
 =head1 SYNOPSIS
 
 Password Safe implementation of L<Passwd::Keyring>. Passwords are
-stored in the Password Safe (L<http://passwordsafe.sourceforge.net>)
-encrypted file.
+stored in the Password Safe encrypted file (see
+L<http://passwordsafe.sourceforge.net> for details,
+Windows and Linux versions are available).
 
 This module does not require Password Safe to be installed, and can be
 used as generic "store many passwords in file encrypted with single
@@ -45,7 +46,7 @@ with other Passwd::Keyring backends.
          app=>"blahblah scraper",
          group=>"Johnny web scrapers",
          file=>"/home/joe/secrets.pwsafe3",        # HOME / passwd-keyring.pwsafe3 by default
-         master_password=>"very secret password",  # Or callback. See ->new docs below
+         master_password=>"very secret password",  # Or callback. See below
     );
 
     my $username = "John";  # or get from .ini, or from .argv...
@@ -64,19 +65,19 @@ with other Passwd::Keyring backends.
     }
 
 Note: see L<Passwd::Keyring::Auto::KeyringAPI> for detailed comments
-on keyring method semantics (this document is installed with
+on keyring methods (this document is installed with
 C<Passwd::Keyring::Auto> package).
 
 =head1 CAVEATS
 
 Underlying module (L<Crypt::PWSafe3>) in fact rewrites the whole file
-on every save (with the complete password list as read on init). This
-means that any attempts to use the file paralelly from a few programs,
-or from a few objects within one program, are doomed to cause lost
-updates. Also, all passwords from the file are kept in (unprotected)
-memory while keyring object is active. Therefore, it is recommended to
-use separate .psafe3 file for Passwd::Keyring::PWSafe3, not mixing it
-with possibly used normal Password Safe database, and to keep keyring
+on every save and keeps all passwords cached in memory while active.
+This means, that any attempts to use the file paralelly from a few
+programs, or from a few objects within one program, are doomed to
+cause lost updates. Also, all passwords from the file are kept in
+(unprotected) memory while keyring object is active. Therefore, it is
+recommended to use separate .psafe3 file for Passwd::Keyring::PWSafe3,
+not mixing it with normal Password Safe database, and to keep keyring
 object for a short time only, especially if modifications happen.
 
 There are some limitations in L<Crypt::PWSafe3> handling of Password
@@ -100,30 +101,54 @@ Username and password are ... well, used as username and password.
 Initializes the processing. Croaks if Crypt::PWSafe3 is not installed or
 master password is invalid. May create password file if it is missing.
 
-Handled named parameters: 
+Handled parameters:
 
-- app - symbolic application name (used in password notes)
+=over 4
 
-- group - name for the password group (used as folder name)
+=item app
 
-- file - location of .pwsafe3 file. If not given, C<passwd-keyring.pwsafe3> in user home directory is used. Will be created if does not exist. Note: absolute path is required, relative paths are very error prone.
+Symbolic application name (used in password notes)
 
-- master_password - password required to unlock the file. Can be
-  specified as string, or as callback returning a string (usually some
-  way of interactively asking user for the password).  The callback
-  gets two parameters: app and file.
+=item group
 
-  If this param is missing, module will prompt interactively for this
-  password using console prompt.
+Name for the password group (used as folder name)
 
-- lazy_save - if given, asks not to save the file after every change
-  (saving is fairly time consuming), but only when $keyring->save
-  is called or when keyring is destroyed.
+=item file
 
-Note: it of course does not make much sense to keep app passwords in encrypted
-storage if master password is saved in plain text. The module most natural
-usage is to interactively ask for master password (and use it to protect
-noticeable number of application-specific passwords).
+Location of .pwsafe3 file. If not given, C<passwd-keyring.pwsafe3> in
+user home directory is used. Will be created if does not exist. Note:
+absolute path is required, relative paths are very error prone.
+
+=item master_password 
+
+Password required to unlock the file. Can be Specified as string, or
+as callback returning a string (usually some way of interactively
+asking user for the password).  The callback gets two parameters: app
+and file.
+
+If this param is missing, module will prompt interactively for this
+password using console prompt.
+
+=item lazy_save
+
+if given, asks not to save the file after every change (saving is
+fairly time consuming), but only when $keyring->save is called or when
+keyring is destroyed.
+
+=back
+
+Note: it of course does not make much sense to keep app passwords in
+encrypted storage if master password is saved in plain text. The
+module most natural usage is to interactively ask for master password
+(and use it to protect noticeable number of application-specific
+passwords).
+
+Ideas of how to workaround this obstacle are welcome. I loosely
+consider either caching master password per desktop session
+(implementing sht. similar to ssh-agent/gpg-agent or using one of
+those somehow), or integrating the tool with PAM to use actual system
+password, or both - but while it seems doable on Linux, cross platform
+solution is not so easy.
 
 =cut
 
